﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Threading;

using SmartX;
using INT_PT002.DataStore;
using INT_PT002.Controls;
using INT_PT002.Part11_UserManager;
using INT_PT002.DialogForms;

namespace INT_PT002.Forms
{
    public partial class FormMainDisplay2 : Form
    {
        #region Field
        private int FlagIgnoreCNT;

        private string MessageBoxRange;

        private Color ColorProgressOn;
        private Color ColorProgressOff;
        private Color ColorResultPass;
        private Color ColorResultNG;
        private Color ColorResultNone;
        private Color ColorSensorNormal;
        private Color ColorSensorError;

        private Collection<SmartLabel> CollectionLabelResult;
        private Collection<SmartLabel> CollectionLabelPressure;
        private Collection<SmartLabel> CollectionLabelLeakRatePerSec;
        private Collection<SmartLabel> CollectionLabelSbAlarm;

        private FormMain m_ParentForm;

        private ControlMainDisplay ChildControl;
        #endregion

        #region Constructor
        public FormMainDisplay2(FormMain parent)
        {
            InitializeComponent();

            this.ParentForm = parent;

            this.DefaultSetting();
            this.InitializeData();
        } 
        #endregion

        #region Property
        public FormMain ParentForm
        {
            get { return this.m_ParentForm; }
            private set { this.m_ParentForm = value; }
        }
        #endregion

        #region Method
        private void DefaultSetting()
        {
            this.FlagIgnoreCNT = 0;
            this.MessageBoxRange = "";

            this.ColorProgressOff = Color.FromArgb(100, 101, 103);
            this.ColorProgressOn = Color.FromArgb(0, 118, 222);
            this.ColorResultPass = Color.FromArgb(39, 200, 64);
            this.ColorResultNG = Color.FromArgb(254, 70, 70);
            this.ColorResultNone = Color.FromArgb(42, 43, 45);
            this.ColorSensorNormal = Color.FromArgb(39, 200, 64);
            this.ColorSensorError = Color.FromArgb(254, 70, 70);

            this.CollectionLabelResult = new Collection<SmartLabel>();
            this.CollectionLabelResult.Add(this.labelResult1);
            this.CollectionLabelResult.Add(this.labelResult2);
            this.CollectionLabelResult.Add(this.labelResult3);
            this.CollectionLabelResult.Add(this.labelResult4);
            this.CollectionLabelResult.Add(this.labelResult5);
            this.CollectionLabelResult.Add(this.labelResult6);
            this.CollectionLabelResult.Add(this.labelResult7);
            this.CollectionLabelResult.Add(this.labelResult8);
            this.CollectionLabelResult.Add(this.labelResult9);
            this.CollectionLabelResult.Add(this.labelResult10);

            this.CollectionLabelPressure = new Collection<SmartLabel>();
            this.CollectionLabelPressure.Add(this.labelPressure1);
            this.CollectionLabelPressure.Add(this.labelPressure2);
            this.CollectionLabelPressure.Add(this.labelPressure3);
            this.CollectionLabelPressure.Add(this.labelPressure4);
            this.CollectionLabelPressure.Add(this.labelPressure5);
            this.CollectionLabelPressure.Add(this.labelPressure6);
            this.CollectionLabelPressure.Add(this.labelPressure7);
            this.CollectionLabelPressure.Add(this.labelPressure8);
            this.CollectionLabelPressure.Add(this.labelPressure9);
            this.CollectionLabelPressure.Add(this.labelPressure10);

            this.CollectionLabelLeakRatePerSec = new Collection<SmartLabel>();
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec1);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec2);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec3);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec4);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec5);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec6);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec7);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec8);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec9);
            this.CollectionLabelLeakRatePerSec.Add(this.labelLrSec10);

            this.CollectionLabelSbAlarm = new Collection<SmartLabel>();
            this.CollectionLabelSbAlarm.Clear();
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm1);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm2);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm3);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm4);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm5);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm6);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm7);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm8);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm9);
            this.CollectionLabelSbAlarm.Add(this.labelSbAlarm10);

            this.ChildControl = new ControlMainDisplay(this.ParentForm);
            this.Controls.Add(this.ChildControl);
            this.ChildControl.Location = new Point(0, 118);
            this.ChildControl.BringToFront();
            this.ChildControl.Visible = false;

            this.buttonRecipeNo.ButtonText = this.ParentForm.SystemConfig.RECIPE_NUMBER.ToString();
        }
        private void InitializeData()
        {
            for (int i = 0; i < this.ParentForm.CurrentSystemStatus.EquipmentColumn; i++)
            {
                this.CollectionLabelResult[i].Visible = false;
                this.CollectionLabelPressure[i].Text = "0";
                this.CollectionLabelLeakRatePerSec[i].Text = "0";
                this.CollectionLabelSbAlarm[i].Visible = false;
            }
        }

        private bool UI_Invoke(ThreadStart invoker)
        {
            try
            {
                if (this.InvokeRequired)
                {
                    if (this.IsDisposed)
                        return true;

                    this.Invoke(invoker);
                }
                else
                {
                    invoker();
                }

                return true;

            }
            catch (Exception e)
            {
                return false;
            }

        }

        private void Login()
        {
            DialogFormLogOn logOn = new DialogFormLogOn(this.ParentForm);
            if (logOn.ShowDialog() == DialogResult.OK)
            {
                this.DisplayRefresh();
                this.buttonUser.ButtonDown();
                //this.ParentForm.TimerAutomaticLogout(true, this.ParentForm.SystemConfig.AutomaticLogout);

                // Part 11
                this.ParentForm.SetTrackingHistoryData(Define.E_TrackingOperation.Login, "");
            }
            else
            {
                this.buttonUser.ButtonUp();
            }
        }
        public void Logout()
        {
            this.ParentForm.SystemConfig.CURRENT_USER.Status = Define.E_UserStatus.LogOff;
            this.buttonUser.ButtonUp();
            this.DisplayRefresh();

            // Part 11
            this.ParentForm.SetTrackingHistoryData(Define.E_TrackingOperation.Logout, "");
        }
        public void Part11AutomaticLogoutReset()
        {
            //UserManager.UserManager_AutoLogoutTimeoutReset();
        }

        public void CallBackUserListLoginTimeoutDataEvent(UserManager.UserMgr_login_timeout_t user)
        {
            string code = "", message1 = "", message2 = "";
            int warningTime = 0;

            if (user.remainder_time != 0)
            {
                switch (this.ParentForm.SystemConfig.LANGUAGE)
                {
                    case Define.E_LanguageID.Korean:
                        code = "로그인";
                        message1 = "잠시 후에 로그아웃 됩니다";
                        message2 = "";
                        break;
                    case Define.E_LanguageID.English:
                        code = "Login";
                        message1 = "You will be logged out after a while";
                        message2 = "";
                        break;
                    default:
                        break;
                }

                warningTime = this.ParentForm.FlagAutomaticLogoutWarningTime - 2;

                this.UI_Invoke(delegate
                {
                    DialogFormMessage msg = new DialogFormMessage(Define.E_MessageBoxIcon.Asterisk, code, message1, message2, warningTime);
                    msg.ShowDialog();
                });
            }
            else
            {
                switch (this.ParentForm.SystemConfig.LANGUAGE)
                {
                    case Define.E_LanguageID.Korean:
                        code = "Login";
                        message1 = "자동 로그아웃 되었습니다";
                        message2 = "";
                        break;
                    case Define.E_LanguageID.English:
                        code = "Login";
                        message1 = "automatically logged out";
                        message2 = "";
                        break;
                    default:
                        break;
                }

                // User Logout
                UserManager.UserManager_UserLogout();

                this.UI_Invoke(delegate
                {
                    this.Logout();
                });

                this.UI_Invoke(delegate
                {
                    DialogFormMessage msg = new DialogFormMessage(Define.E_MessageBoxIcon.Asterisk, code, message1, message2, 0);
                    msg.ShowDialog();
                });
            }
        }

        private void GetJudgmentResult(Define.E_JudgmentStatus judg, SmartLabel label)
        {
            string value = "";

            switch (judg)
            {
                case Define.E_JudgmentStatus.None:
                    value = "-";
                    label.BackGroundColor = this.ColorResultNone;
                    break;
                case Define.E_JudgmentStatus.Pass:
                    value = "Pass";
                    label.BackGroundColor = this.ColorResultPass;
                    break;
                case Define.E_JudgmentStatus.Ng:
                    value = "Leak";
                    label.BackGroundColor = this.ColorResultNG;
                    break;
                case Define.E_JudgmentStatus.Error:
                    value = "Empty";
                    label.BackGroundColor = this.ColorResultNone;
                    break;
                default:
                    break;
            }

            if (label.Text != value)
                label.Text = value;
        }

        public void UpdateProcessStatusDisplay(Define.E_ProcessStatus status)
        {
            switch (status)
            {
                case Define.E_ProcessStatus._0_None:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;
                    break;
                case Define.E_ProcessStatus._1_Initial:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;

                    this.buttonInspection.Enabled = true;
                    break;
                case Define.E_ProcessStatus._2_ProductEntry:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;

                    this.buttonInspection.Enabled = false;
                    // Label Initialize
                    //this.InitializeLabel();
                    break;
                case Define.E_ProcessStatus._3_ChamberConbined:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;
                    break;
                case Define.E_ProcessStatus._4_VacuumStart:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;
                    break;
                case Define.E_ProcessStatus._5_VacuumHold:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;
                    break;
                case Define.E_ProcessStatus._6_Judgment:
                    break;
                case Define.E_ProcessStatus._7_VacuumBreak:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;
                    break;
                case Define.E_ProcessStatus._8_ChamberSeparation:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOn;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOff;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOn;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOff;
                    break;
                case Define.E_ProcessStatus._9_ProductRelease:
                    this.labelProgress0.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress1.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress2.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress3sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress4sec.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress7.RoundRectFillColor = this.ColorProgressOff;
                    this.labelProgress8.RoundRectFillColor = this.ColorProgressOn;

                    this.labelProgress0_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress1_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress2_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress3_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress4_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress6_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress7_1.BackGroundColor = this.ColorProgressOff;
                    this.labelProgress8_1.BackGroundColor = this.ColorProgressOn;
                    break;
                default:
                    break;
            }
        }
        private void UpdateDisplayDotGraphDiff(SmartDraw draw, DiffData diff)
        {
            int iValue = 0;
            double dValue = 0.0;

            // 값 표시 범위
            // 15.000 ~ -2.000  (17.000 ~ 0)
            // 그래프 영역 높이 102
            // 17000 / 102 = 166.666666~
            //dValue = (int.Parse(data.CurrentValueSign + data.CurrentValue) + 2000) / 166.66666;

            if (dValue > 110)
                dValue = 110;
            if (dValue < 1)
                dValue = 1;

            iValue = int.Parse(string.Format("{0:f0}", dValue));
            
            draw.Chart.PutData(iValue);
        }
        private void UpdateDisplayDotGraphDisp(SmartDraw draw, DispData disp)
        {
            int iValue = 0;
            double dValue = 0.0;

            // 값 표시 범위
            // 15.000 ~ -2.000  (17.000 ~ 0)
            // 그래프 영역 높이 102
            // 17000 / 102 = 166.666666~
            //dValue = (int.Parse(data.CurrentValueSign + data.CurrentValue) + 2000) / 166.66666;

            if (dValue > 110)
                dValue = 110;
            if (dValue < 1)
                dValue = 1;

            iValue = int.Parse(string.Format("{0:f0}", dValue));

            draw.Chart.PutData(iValue);
        }
        public void UpdateEquipmentStatusDisplay(Define.E_EquipmentStatus status)
        {
            if (status == Define.E_EquipmentStatus.Start)
            {
                #region Start
                this.labelStart.Visible = true;
                this.labelStop.Visible = false;
                #endregion
            }
            else
            {
                #region Stop
                this.labelStart.Visible = false;
                this.labelStop.Visible = true;
                #endregion
            }
        }
        public void UpdateDisplayAlarmView(AlarmList alarm)
        {
            string value = "";

            // ServoEmergencyStop
            if (alarm.IsServoEmergencyStop == true)
                value = "a1_Servo emergency stop     ";
            // Servo1Alarm
            if (alarm.IsServo1Alarm == true)
                value += "a2_Servo1     ";
            // Servo2Alarm
            if (alarm.IsServo2Alarm == true)
                value += "a3_Servo2     ";
            // ServoTorque1AlarmTorque 
            if (alarm.IsServoTorque1AlarmTorque == true)
                value += "a4_Servo1 Torque     ";
            // ServoTorque2AlarmTorque 
            if (alarm.IsServoTorque2AlarmTorque == true)
                value += "a5_Servo2 Torque     ";
            // PressureError
            if (alarm.IsPressureError == true)
                value += "a6_Pressure     ";

            // SB Alarm
            this.CollectionLabelSbAlarm[0].Visible = alarm.CollectionIsSensorBoardError[0];
            this.CollectionLabelSbAlarm[1].Visible = alarm.CollectionIsSensorBoardError[1];
            this.CollectionLabelSbAlarm[2].Visible = alarm.CollectionIsSensorBoardError[2];
            this.CollectionLabelSbAlarm[3].Visible = alarm.CollectionIsSensorBoardError[3];
            this.CollectionLabelSbAlarm[4].Visible = alarm.CollectionIsSensorBoardError[4];
            this.CollectionLabelSbAlarm[5].Visible = alarm.CollectionIsSensorBoardError[5];
            this.CollectionLabelSbAlarm[6].Visible = alarm.CollectionIsSensorBoardError[6];
            this.CollectionLabelSbAlarm[7].Visible = alarm.CollectionIsSensorBoardError[7];
            this.CollectionLabelSbAlarm[8].Visible = alarm.CollectionIsSensorBoardError[8];
            this.CollectionLabelSbAlarm[9].Visible = alarm.CollectionIsSensorBoardError[9];

            value = value.Trim();
            this.label1.Size = new Size(value.Length * 7, 20);
            this.label1.Text = value;

            if (this.label1.Width > 655)
            {
                if (this.label1.Text != "")
                    this.smartTimerAlarm.Start();
            }
        }
        public void UpdateDisplayDiffData(Collection<DiffData> datas)
        {
            for (int i = 0; i < this.ParentForm.CurrentSystemStatus.EquipmentColumn; i++)
                this.CollectionLabelLeakRatePerSec[i].Text = datas[i].SecBufDiff;
        }
        public void UpdateDisplayDispData(Collection<DispData> datas)
        {
           
        }
        public void UpdateDisplayPresData(Collection<PressureData> datas)
        {
            for (int i = 0; i < this.ParentForm.CurrentSystemStatus.EquipmentColumn; i++)
                this.CollectionLabelPressure[i].Text = datas[i].WorkingChamber.Trim() + " kPa";
        }
        public void UpdateDisplayJudgmentData(LeakData datas)
        {
            for (int i = 0; i < this.ParentForm.CurrentSystemStatus.EquipmentColumn; i++)
            {
                this.GetJudgmentResult(datas.CollJudgment[i], this.CollectionLabelResult[i]);
                this.CollectionLabelResult[i].Visible = true;
            }

            this.ParentForm.TrackingInspectionData(datas);
            this.ChildControl.UpdateStartLeakDataDisplay(datas);
        }
        public void UpdateDisplayRecipeData(Recipe data)
        {
            this.buttonRecipeNo.ButtonText = data.NUMBER.ToString();
        }
        public void UpdateDisplayTime()
        {
            this.labelTime.Text = DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss");
        }

        public void DisplayRefresh()
        {
            this.ParentForm.CurrentSystemStatus.CurrentDisplay = Define.E_FormStore.FormMainDisplay;
            this.ParentForm.SetDisplayMode(Define.E_DisplayMode.Normal);

            this.buttonRecipeNo.ButtonText = this.ParentForm.CurrentRecipe.NUMBER.ToString();
        }
        #endregion

        #region Event Handler
        private void labelStop_Click(object sender, EventArgs e)
        {
            this.ParentForm.TransferData(CommunicationCommand.Start, CommunicationID.MainBoard);
        }
        private void labelStart_Click(object sender, EventArgs e)
        {
            this.ParentForm.TransferData(CommunicationCommand.Stop, CommunicationID.MainBoard);
        }

        private void buttonProductNo_Click(object sender, EventArgs e)
        {
            string afterValue = "";

            afterValue = this.buttonRecipeNo.ButtonText;
            DialogFormNumKeyPad myKeypad = new DialogFormNumKeyPad("NUMBER", this.buttonRecipeNo.ButtonText, 4, 0, false);

            if (myKeypad.ShowDialog() == DialogResult.OK)
            {
                if (myKeypad.IntValue < 1 || myKeypad.IntValue > 1000)
                {
                    this.MessageBoxRange = "1 ~ 1000";
                    this.buttonRecipeNo.ButtonText = afterValue;
                    this.smartTimerMessageShow.Start();
                    return;
                }

                this.buttonRecipeNo.ButtonText = "**";
                this.ParentForm.TransferRecipeParameter9043(myKeypad.IntValue);
            }
        }
        private void buttonDisplayGraph_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(1);
            this.ChildControl.Visible = true;
        }
        private void buttonInspection_Click(object sender, EventArgs e)
        {
            this.ParentForm.TransferData(CommunicationCommand.CutInpupt, CommunicationID.MainBoard);

            this.InitializeData();
            this.ChildControl.ClearAllData();
        }
        private void buttonUser_Click(object sender, EventArgs e)
        {

        }
        private void buttonMenu_Click(object sender, EventArgs e)
        {
            if (this.ParentForm.CurrentSystemStatus.EquipmentStatus == Define.E_EquipmentStatus.Stop)
            {
                this.ParentForm.ChildFormMenu.DisplayRefresh(this.ParentForm.CurrentSystemStatus);
                this.ParentForm.FormChange((int)Define.E_FormStore.FormMenu);
            }
        }

        private void smartDraw1_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(1);
            this.ChildControl.Visible = true;
        }
        private void smartDraw2_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(2);
            this.ChildControl.Visible = true;
        }
        private void smartDraw3_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(3);
            this.ChildControl.Visible = true;
        }
        private void smartDraw4_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(4);
            this.ChildControl.Visible = true;
        }
        private void smartDraw5_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(5);
            this.ChildControl.Visible = true;
        }
        private void smartDraw6_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(6);
            this.ChildControl.Visible = true;
        }
        private void smartDraw7_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(7);
            this.ChildControl.Visible = true;
        }
        private void smartDraw8_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(8);
            this.ChildControl.Visible = true;
        }
        private void smartDraw9_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(9);
            this.ChildControl.Visible = true;
        }
        private void smartDraw10_Click(object sender, EventArgs e)
        {
            this.ChildControl.DisplayRefresh(10);
            this.ChildControl.Visible = true;
        }
        private void buttonClear_Click(object sender, EventArgs e)
        {
            this.InitializeData();
            this.ChildControl.ClearAllData();
        }

        private void buttonExit_Click(object sender, EventArgs e)
        {
            this.ParentForm.CloseSmartUartLink();
            this.ParentForm.Dispose();
            this.ParentForm.Close();
        }

        private void smartTimerAlarm_Tick(object sender, EventArgs e)
        {
            this.label1.Left = this.label1.Left - 5;
            if (this.label1.Left < 0 - this.label1.Width - 20)
                this.label1.Left = this.smartGroupBox1.Width - 10;
        }
        private void smartTimerMessageShow_Tick(object sender, EventArgs e)
        {
            this.smartTimerMessageShow.Stop();

            DialogFormMessage msg = new DialogFormMessage(1, this.ParentForm.SystemConfig.LANGUAGE, this.MessageBoxRange);
            msg.ShowDialog();
        }
        #endregion
        private void smartButton1_Click(object sender, EventArgs e)
        {
            string value = "";

            value = "a1_Servo emergency stop     ";
            value += "a2_Servo1     ";
            value += "a3_Servo2     ";
            //value += "a4_Servo1 Torque     ";
            //value += "a5_Servo2 Torque     ";
            //value += "a6_Pressure     ";

            value = value.Trim();
            this.label1.Size = new Size(value.Length * 7, 20);
            this.label1.Text = value;

            if (this.label1.Text != "")
                this.smartTimerAlarm.Start();
        }
    }
}